==> jc-1.4.0.tar.gz: javax/swing/ProgressMonitorInputStream.h <==
// public class javax.swing.ProgressMonitorInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class aca165da3feb7c79 javax_swing_ProgressMonitorInputStream

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_javax_swing_ProgressMonitorInputStream_H_
#define _JC_javax_swing_ProgressMonitorInputStream_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_ProgressMonitor$object;

// Typedefs
typedef struct _jc_javax_swing_ProgressMonitorInputStream$sub_refs	_jc_javax_swing_ProgressMonitorInputStream$sub_refs;
typedef struct _jc_javax_swing_ProgressMonitorInputStream$sub_nonrefs	_jc_javax_swing_ProgressMonitorInputStream$sub_nonrefs;
typedef struct _jc_javax_swing_ProgressMonitorInputStream$refs	_jc_javax_swing_ProgressMonitorInputStream$refs;
typedef struct _jc_javax_swing_ProgressMonitorInputStream$nonrefs	_jc_javax_swing_ProgressMonitorInputStream$nonrefs;
typedef struct _jc_javax_swing_ProgressMonitorInputStream$object	_jc_javax_swing_ProgressMonitorInputStream$object;

typedef const struct _jc_javax_swing_ProgressMonitorInputStream$vmethods	_jc_javax_swing_ProgressMonitorInputStream$vmethods;
typedef const struct _jc_javax_swing_ProgressMonitorInputStream$vtable	_jc_javax_swing_ProgressMonitorInputStream$vtable;
typedef const struct _jc_javax_swing_ProgressMonitorInputStream$vtype	_jc_javax_swing_ProgressMonitorInputStream$vtype;

// Constructors
extern void _jc_javax_swing_ProgressMonitorInputStream$method$_init$85fee992be3119da(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, struct _jc_java_awt_Component$object *, struct _jc_java_lang_Object$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern void _jc_javax_swing_ProgressMonitorInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *);
extern struct _jc_javax_swing_ProgressMonitor$object *_jc_javax_swing_ProgressMonitorInputStream$method$getProgressMonitor$ccdf9c55c185e8ff(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *);
extern jint _jc_javax_swing_ProgressMonitorInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *);
extern jint _jc_javax_swing_ProgressMonitorInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, struct _jc_byte_array *);
extern jint _jc_javax_swing_ProgressMonitorInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_javax_swing_ProgressMonitorInputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *);
extern jlong _jc_javax_swing_ProgressMonitorInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, jlong);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$getProgressMonitor$ccdf9c55c185e8ff;
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_javax_swing_ProgressMonitorInputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *);
	struct _jc_javax_swing_ProgressMonitor$object	*(*getProgressMonitor$ccdf9c55c185e8ff)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *);
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, struct _jc_byte_array *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *);
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, jlong);
};

// Vtable
struct _jc_javax_swing_ProgressMonitorInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_javax_swing_ProgressMonitorInputStream$vmethods	javax_swing_ProgressMonitorInputStream;
};

// Vtype
struct _jc_javax_swing_ProgressMonitorInputStream$vtype {
	_jc_type			type;
	_jc_javax_swing_ProgressMonitorInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ProgressMonitorInputStream$sub_refs {
	struct _jc_javax_swing_ProgressMonitor$object	*monitor;
};

// Reference instance fields (object)
struct _jc_javax_swing_ProgressMonitorInputStream$refs {
    _jc_javax_swing_ProgressMonitorInputStream$sub_refs	javax_swing_ProgressMonitorInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ProgressMonitorInputStream$sub_nonrefs {
	jint	nread;
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ProgressMonitorInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_javax_swing_ProgressMonitorInputStream$sub_nonrefs	javax_swing_ProgressMonitorInputStream;
};

// Object instance structure
struct _jc_javax_swing_ProgressMonitorInputStream$object {
	_jc_javax_swing_ProgressMonitorInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ProgressMonitorInputStream$vtype	*vtype;
	_jc_javax_swing_ProgressMonitorInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ProgressMonitorInputStream$vtype _jc_javax_swing_ProgressMonitorInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ProgressMonitorInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ProgressMonitorInputStream$class_object;

#endif	/* _JC_javax_swing_ProgressMonitorInputStream_H_ */

==> jc-1.4.6.tar.gz: javax/swing/ProgressMonitorInputStream.h <==
// public class javax.swing.ProgressMonitorInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class aca165da3feb7c79 javax_swing_ProgressMonitorInputStream

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_javax_swing_ProgressMonitorInputStream_H_
#define _JC_javax_swing_ProgressMonitorInputStream_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_ProgressMonitor$object;

// Typedefs
typedef struct _jc_javax_swing_ProgressMonitorInputStream$sub_refs	_jc_javax_swing_ProgressMonitorInputStream$sub_refs;
typedef struct _jc_javax_swing_ProgressMonitorInputStream$sub_nonrefs	_jc_javax_swing_ProgressMonitorInputStream$sub_nonrefs;
typedef struct _jc_javax_swing_ProgressMonitorInputStream$refs	_jc_javax_swing_ProgressMonitorInputStream$refs;
typedef struct _jc_javax_swing_ProgressMonitorInputStream$nonrefs	_jc_javax_swing_ProgressMonitorInputStream$nonrefs;
typedef struct _jc_javax_swing_ProgressMonitorInputStream$object	_jc_javax_swing_ProgressMonitorInputStream$object;

typedef const struct _jc_javax_swing_ProgressMonitorInputStream$vmethods	_jc_javax_swing_ProgressMonitorInputStream$vmethods;
typedef const struct _jc_javax_swing_ProgressMonitorInputStream$vtable	_jc_javax_swing_ProgressMonitorInputStream$vtable;
typedef const struct _jc_javax_swing_ProgressMonitorInputStream$vtype	_jc_javax_swing_ProgressMonitorInputStream$vtype;

// Constructors
extern void _jc_javax_swing_ProgressMonitorInputStream$method$_init$85fee992be3119da(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, struct _jc_java_awt_Component$object *, struct _jc_java_lang_Object$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_ProgressMonitorInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_ProgressMonitor$object *_jc_javax_swing_ProgressMonitorInputStream$method$getProgressMonitor$ccdf9c55c185e8ff(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_ProgressMonitorInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_ProgressMonitorInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_ProgressMonitorInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_ProgressMonitorInputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *) _JC_JCNI_ATTR;
extern jlong _jc_javax_swing_ProgressMonitorInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, jlong) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$getProgressMonitor$ccdf9c55c185e8ff;
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_javax_swing_ProgressMonitorInputStream$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_javax_swing_ProgressMonitorInputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *) _JC_JCNI_ATTR;
	struct _jc_javax_swing_ProgressMonitor$object	*(*getProgressMonitor$ccdf9c55c185e8ff)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *) _JC_JCNI_ATTR;
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_javax_swing_ProgressMonitorInputStream$object *, jlong) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_ProgressMonitorInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_javax_swing_ProgressMonitorInputStream$vmethods	javax_swing_ProgressMonitorInputStream;
};

// Vtype
struct _jc_javax_swing_ProgressMonitorInputStream$vtype {
	_jc_type			type;
	_jc_javax_swing_ProgressMonitorInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ProgressMonitorInputStream$sub_refs {
	struct _jc_javax_swing_ProgressMonitor$object	*monitor;
};

// Reference instance fields (object)
struct _jc_javax_swing_ProgressMonitorInputStream$refs {
    _jc_javax_swing_ProgressMonitorInputStream$sub_refs	javax_swing_ProgressMonitorInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ProgressMonitorInputStream$sub_nonrefs {
	jint	nread;
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ProgressMonitorInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_javax_swing_ProgressMonitorInputStream$sub_nonrefs	javax_swing_ProgressMonitorInputStream;
};

// Object instance structure
struct _jc_javax_swing_ProgressMonitorInputStream$object {
	_jc_javax_swing_ProgressMonitorInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ProgressMonitorInputStream$vtype	*vtype;
	_jc_javax_swing_ProgressMonitorInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ProgressMonitorInputStream$vtype _jc_javax_swing_ProgressMonitorInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ProgressMonitorInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ProgressMonitorInputStream$class_object;

#endif	/* _JC_javax_swing_ProgressMonitorInputStream_H_ */
